#ifndef __PROPPWR
#define __PROPPWR


class QLabel;
class QPushButton;
class KLineEdit;
class QRadioButton;
class QButtonGroup;

class PropPwr : public QDialog
{
    Q_OBJECT

public:
    PropPwr(QWidget *, const char *, Circuit *, XDevice *);

private:
    void done(int);

    QPushButton *bOK;
    QPushButton *bCancel;
    QLabel *label0;
    KLineEdit *devname;
    QButtonGroup *bgPwr;
    QRadioButton *rbPlus;
    QRadioButton *rbMinus;
    Circuit *dnet;
    XDevice *dev;
};

#endif
